Name:       wasi-libc
Summary:    C library implementation for WebAssembly System Interface
Version:    22
Release:    1%{?dist}

License:    Apache-2.0 WITH LLVM-exception AND Apache-2.0 AND MIT AND BSD-2-Clause
URL:        https://github.com/WebAssembly/wasi-libc/
Source0:     %{url}/archive/refs/tags/wasi-sdk-%{version}.tar.gz#/%{name}-wasi-sdk-%{version}.tar.gz
Source1:    smoke-test.c

Patch:      0001-make-don-t-rebuild-files-on-make-install.patch

%global     musl_version 1.2.3

%global     _binaries_in_noarch_packages_terminate_build 0
BuildArch:  noarch

BuildRequires:  clang >= 10
BuildRequires:  git-core
BuildRequires:  llvm >= 10
BuildRequires:  make

%global     toolchain clang
%global     __brp_llvm_compile_lto_elf %{nil}

%global     build_cflags --target=wasm32-wasi -fstack-protector
%global     wasi_prefix %{_prefix}/wasm32-wasi
%global     wasi_datadir %{wasi_prefix}/share
%global     wasi_includedir %{wasi_prefix}/include
%global     wasi_libdir %{wasi_prefix}/lib
%global     wasi_make_flags MALLOC_IMPL=emmalloc INSTALL_DIR='%{buildroot}%{wasi_prefix}' SYSROOT='%{_builddir}/sysroot'

%global _description %{expand:
WASI Libc is a libc for WebAssembly programs built on top of WASI system calls.
It provides a wide array of POSIX-compatible C APIs, including support for
standard I/O, file I/O, filesystem manipulation, memory management, time,
string, environment variables, program startup, and many other APIs.}

%description %{_description}

%package static
Provides: bundled(musl) = %{musl_version}
Summary:  C library for WASI - static libraries

%description static %{_description}

%package devel
Requires: %{name}-static  = %{version}-%{release}
Provides: bundled(musl) = %{musl_version}
Summary:  C library for WASI - headers and development files

%description devel %{_description}


%prep
%autosetup -n %{name}-wasi-sdk-%{version} -S git_am
cp -p libc-bottom-half/cloudlibc/LICENSE LICENSE-cloudlibc

%build
%make_build %{wasi_make_flags}
make %{?_smp_mflags} %{wasi_make_flags} check-symbols

%install
%make_install %{wasi_make_flags}

%global __os_install_post %{expand:
    %__os_install_post
    find %{buildroot}%{wasi_libdir} -type f -regex '.*\\.\\(a\\|rlib\\)' -print -exec llvm-ranlib '{}' ';'
}

%check
xargs test '%{musl_version}' = <libc-top-half/musl/VERSION

%files static
%doc README.md
%license LICENSE LICENSE-APACHE LICENSE-APACHE-LLVM LICENSE-MIT LICENSE-cloudlibc
%dir %{wasi_prefix}
%{wasi_libdir}

%files devel
%doc README.md
%license LICENSE LICENSE-APACHE LICENSE-APACHE-LLVM LICENSE-MIT LICENSE-cloudlibc
%dir %{wasi_prefix}
%{wasi_datadir}
%{wasi_includedir}

%changelog
* Fri Aug 23 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 22-1
- initial build
